@@ -3,5 +3,5 @@ from .torch_wrappers import *
 __all__ = [
     "TorchLinearRegression",
     "TorchBinaryLogisticRegression",
-    "TorchNeuralNetwork",
+    "TorchMLP",
 ]
